/*
 * (C) Copyright IBM Corp. 1997-1998  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.parser;

/**
 *
 * @version 19980206
 * @author TAMURA Kent &lt;kent@trl.ibm.co.jp&gt;
 */
public interface ElementFactory {
    /**
     * Create <code>TXElement</code> instance.
     * This method is called after parsing start-tag before parsing its children.
     */
    public TXElement createElement(String name);

    /**
     * Create <code>TXElement</code> instance.
     * This method is called after parsing start-tag before parsing its children.
     */
    public TXElement createElement(String qname, String ns, String n);

    /**
     * This method is called after parsing end-tag.
     */
    public void ripenElement(TXElement el);

    /**
     * Create <code>TXText</code> instance.
     */
    public TXText createText(String data);
    /**
     * Create <code>TXText</code> instance.
     */
    public TXText createText(String data, boolean ignorable);

    /**
     * Create <code>TXCDATASection</code> instance.
     */
    public TXCDATASection createCDATA(String data);

    /**
     * Create <code>TXComment<code> instance.
     */
    public TXComment createComment(String data);

    /**
     * Create <code>TXPI<code> instance.
     */
    public TXPI createPI(String name, String data);

    /**
     * Create <code>TXDocument<code> instance.
     */
    public TXDocument createDocument();

    /**
     * Create <code>DTD<code> instance.
     */
    public DTD createDTD();

    /**
     * Create <code>DTD<code> instance.
     */
    public DTD createDTD(String rootname, ExternalID eid);
}
