/*
 * (C) Copyright IBM Corp. 1997-1998  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.parser;

import java.io.*;
import java.net.*;

/**
 * A sample implementation of <code>ErrorListener</code>, <code>StreamProducer</code>.
 * This class prints erros to standard error stream, and produce streams from files and URL.
 *
 * @version 19980206
 * @author TAMURA Kent &lt;kent@trl.ibm.co.jp&gt;
 */
public class Stderr implements ErrorListener, StreamProducer {
    private String m_fname;
    private URL m_u;

    /**
     * Make new Stderr instance.
     * @param fname default file name when error() is called by null fname.
     */
    public Stderr(String fname) {
        m_fname = fname;
        try {
            m_u = new URL(m_fname);
        } catch (MalformedURLException e) {
            try {
                m_u = new URL("file:///"+m_fname);
            } catch (MalformedURLException ex) {
                ex.printStackTrace();
            }
        }
    }

    /**
     * Print error to standard error stream.
     * @see com.ibm.xml.parser.ErrorListener
     */
    public void error(String fname, int lineno, int charoff, Object key, String mes) {
        if (null == fname)  fname = m_fname;
        System.err.println(fname+": "+lineno+", "+(charoff-1)+": "+mes);
    }

    /**
     * Produce InputStream from specified name.
     * @see com.ibm.xml.parser.StreamProducer
     */
    public java.io.InputStream getInputStream(String name, String pubid, String sysid) throws IOException {
        
        URL u = null;
        try {
            u = new URL(m_u, sysid);
        } catch (MalformedURLException e) {
        }
        if (null == u || "file".equalsIgnoreCase(u.getProtocol())) {
            //System.err.println("Message: open file \""+fname+"\"");
            return new FileInputStream(sysid);
        }
        InputStream is = null;
        if (null != u) {
            is = u.openStream();
            //System.err.println("Message: open resource \""+u+"\"");
        }
        return is;
    }
}

